@@ -10,17 +10,15 @@
 #include "parse_utils.h"
 #include "debug.h"
 
-int parse_init(
-	semanage_handle_t* handle,
-	const char* filename,
-	void* parse_arg,
-	parse_info_t** info) {
-	
-	parse_info_t* tmp_info = 
-		(parse_info_t*) malloc(sizeof(parse_info_t));
-		
+int parse_init(semanage_handle_t * handle,
+	       const char *filename, void *parse_arg, parse_info_t ** info)
+{
+
+	parse_info_t *tmp_info = (parse_info_t *) malloc(sizeof(parse_info_t));
+
 	if (!tmp_info) {
-		ERR(handle, "out of memory, could not allocate parse structure");
+		ERR(handle,
+		    "out of memory, could not allocate parse structure");
 		return STATUS_ERR;
 	}
 
@@ -36,22 +34,21 @@ int parse_init(
 	return STATUS_SUCCESS;
 }
 
-void parse_release(
-	parse_info_t* info) {
+void parse_release(parse_info_t * info)
+{
 
 	parse_close(info);
 	parse_dispose_line(info);
 	free(info);
 }
 
-int parse_open(
-	semanage_handle_t* handle, 
-	parse_info_t* info) {
-	
+int parse_open(semanage_handle_t * handle, parse_info_t * info)
+{
+
 	info->file_stream = fopen(info->filename, "r");
 	if (!info->file_stream && (errno != ENOENT)) {
 		ERR(handle, "could not open file %s: %s",
-			info->filename, strerror(errno));
+		    info->filename, strerror(errno));
 		return STATUS_ERR;
 	}
 	if (info->file_stream)
@@ -60,15 +57,16 @@ int parse_open(
 	return STATUS_SUCCESS;
 }
 
-void parse_close(
-	parse_info_t* info) {
+void parse_close(parse_info_t * info)
+{
 
 	if (info->file_stream)
 		fclose(info->file_stream);
 	info->file_stream = NULL;
 }
 
-void parse_dispose_line(parse_info_t* info) {
+void parse_dispose_line(parse_info_t * info)
+{
 	if (info->orig_line) {
 		free(info->orig_line);
 		info->orig_line = NULL;
@@ -79,18 +77,17 @@ void parse_dispose_line(parse_info_t* info) {
 		info->working_copy = NULL;
 	}
 
-        info->ptr = NULL;
+	info->ptr = NULL;
 }
 
-int parse_skip_space(
-	semanage_handle_t* handle, 
-	parse_info_t* info) {
+int parse_skip_space(semanage_handle_t * handle, parse_info_t * info)
+{
 
 	size_t buf_len = 0;
 	ssize_t len;
 	int lineno = info->lineno;
-	char* buffer = NULL;
-	char* ptr;
+	char *buffer = NULL;
+	char *ptr;
 
 	if (info->ptr) {
 		while (*(info->ptr) && isspace(*(info->ptr)))
@@ -103,7 +100,7 @@ int parse_skip_space(
 	parse_dispose_line(info);
 
 	while (info->file_stream &&
-		((len = getline(&buffer, &buf_len, info->file_stream)) > 0)) {
+	       ((len = getline(&buffer, &buf_len, info->file_stream)) > 0)) {
 
 		lineno++;
 
@@ -117,14 +114,14 @@ int parse_skip_space(
 
 		/* Skip comments and blank lines */
 		if ((*ptr) && *ptr != '#') {
-			char* tmp = strdup(buffer);
+			char *tmp = strdup(buffer);
 			if (!tmp)
 				goto omem;
 
-			info -> lineno = lineno;
-			info -> working_copy = buffer;
-			info -> orig_line = tmp;
-			info -> ptr = ptr;
+			info->lineno = lineno;
+			info->working_copy = buffer;
+			info->orig_line = tmp;
+			info->ptr = ptr;
 
 			return STATUS_SUCCESS;
 		}
@@ -135,35 +132,33 @@ int parse_skip_space(
 
 	return STATUS_SUCCESS;
 
-	omem:
+      omem:
 	ERR(handle, "out of memory, could not allocate buffer");
 	free(buffer);
 	return STATUS_ERR;
 }
 
-int parse_assert_noeof(
-	semanage_handle_t* handle,
-	parse_info_t* info) {
+int parse_assert_noeof(semanage_handle_t * handle, parse_info_t * info)
+{
 
 	if (!info->ptr) {
 		ERR(handle, "unexpected end of file (%s: %u)",
-			info->filename, info->lineno);
+		    info->filename, info->lineno);
 		return STATUS_ERR;
 	}
 
 	return STATUS_SUCCESS;
 }
 
-int parse_assert_space(
-	semanage_handle_t* handle, 
-	parse_info_t* info) {
+int parse_assert_space(semanage_handle_t * handle, parse_info_t * info)
+{
 
 	if (parse_assert_noeof(handle, info) < 0)
- 		return STATUS_ERR;
+		return STATUS_ERR;
 
 	if (*(info->ptr) && !isspace(*(info->ptr))) {
 		ERR(handle, "missing whitespace (%s: %u):\n%s",
-			info->filename, info->lineno, info->orig_line);
+		    info->filename, info->lineno, info->orig_line);
 		return STATUS_ERR;
 	}
 
@@ -173,19 +168,17 @@ int parse_assert_space(
 	return STATUS_SUCCESS;
 }
 
-
-int parse_assert_ch(
-	semanage_handle_t* handle,
-	parse_info_t* info, 
-	const char ch) {
+int parse_assert_ch(semanage_handle_t * handle,
+		    parse_info_t * info, const char ch)
+{
 
 	if (parse_assert_noeof(handle, info) < 0)
 		return STATUS_ERR;
 
 	if (*(info->ptr) != ch) {
 		ERR(handle, "expected character \'%c\', but found \'%c\' "
-			"(%s: %u):\n%s", ch, *(info->ptr), info->filename,
-			info->lineno, info->orig_line);
+		    "(%s: %u):\n%s", ch, *(info->ptr), info->filename,
+		    info->lineno, info->orig_line);
 		return STATUS_ERR;
 	}
 
@@ -194,10 +187,9 @@ int parse_assert_ch(
 	return STATUS_SUCCESS;
 }
 
-int parse_assert_str(
-	semanage_handle_t* handle,
-	parse_info_t* info, 
-	const char* assert_str) {
+int parse_assert_str(semanage_handle_t * handle,
+		     parse_info_t * info, const char *assert_str)
+{
 
 	size_t len = strlen(assert_str);
 
@@ -206,8 +198,8 @@ int parse_assert_str(
 
 	if (strncmp(info->ptr, assert_str, len)) {
 		ERR(handle, "experted string \"%s\", but found \"%s\" "
-			"(%s: %u):\n%s", assert_str, info->ptr, 
-			info->filename, info->lineno, info->orig_line);
+		    "(%s: %u):\n%s", assert_str, info->ptr,
+		    info->filename, info->lineno, info->orig_line);
 
 		return STATUS_ERR;
 	}
@@ -216,18 +208,20 @@ int parse_assert_str(
 	return STATUS_SUCCESS;
 }
 
-int parse_optional_ch(parse_info_t* info, const char ch) {
+int parse_optional_ch(parse_info_t * info, const char ch)
+{
 
 	if (!info->ptr)
 		return STATUS_NODATA;
 	if (*(info->ptr) != ch)
 		return STATUS_NODATA;
-		
+
 	info->ptr++;
 	return STATUS_SUCCESS;
 }
 
-int parse_optional_str(parse_info_t* info, const char* str) {
+int parse_optional_str(parse_info_t * info, const char *str)
+{
 	size_t len = strlen(str);
 
 	if (strncmp(info->ptr, str, len))
@@ -237,30 +231,28 @@ int parse_optional_str(parse_info_t* info, const char* str) {
 	return STATUS_SUCCESS;
 }
 
-int parse_fetch_int(
-	semanage_handle_t* handle,
-	parse_info_t* info,
-	int* num,
-	char delim) {
+int parse_fetch_int(semanage_handle_t * handle,
+		    parse_info_t * info, int *num, char delim)
+{
 
-	char* str = NULL;
-	char* test = NULL;
+	char *str = NULL;
+	char *test = NULL;
 	int value = 0;
 
-	if (parse_fetch_string(handle, info, &str, delim) < 0)
+	if (parse_fetch_string(handle, info, &str, delim, 0) < 0)
 		goto err;
 
-	if (!isdigit((int) *str)) {
+	if (!isdigit((int)*str)) {
 		ERR(handle, "expected a numeric value: (%s: %u)\n%s",
-			info->filename, info->lineno, info->orig_line);
+		    info->filename, info->lineno, info->orig_line);
 		goto err;
 	}
 
 	value = strtol(str, &test, 10);
 	if (*test != '\0') {
 		ERR(handle, "could not parse numeric value \"%s\": "
-			"(%s: %u)\n%s", str, info->filename, 
-			info->lineno, info->orig_line);
+		    "(%s: %u)\n%s", str, info->filename,
+		    info->lineno, info->orig_line);
 		goto err;
 	}
 
@@ -268,50 +260,48 @@ int parse_fetch_int(
 	free(str);
 	return STATUS_SUCCESS;
 
-	err:
+      err:
 	ERR(handle, "could not fetch numeric value");
 	free(str);
 	return STATUS_ERR;
 }
 
-int parse_fetch_string(
-	semanage_handle_t* handle,
-	parse_info_t* info, 
-	char** str, 
-	char delim) {
+int parse_fetch_string(semanage_handle_t * handle,
+		       parse_info_t * info, char **str, char delim, int allow_spaces)
+{
 
-	char* start = info->ptr;
+	char *start = info->ptr;
 	int len = 0;
-	char* tmp_str = NULL;
+	char *tmp_str = NULL;
 
 	if (parse_assert_noeof(handle, info) < 0)
 		goto err;
 
-	while (*(info->ptr) && !isspace(*(info->ptr)) &&
-	      (*(info->ptr) != delim)) {
+	while (*(info->ptr) && (allow_spaces || !isspace(*(info->ptr))) &&
+	       (*(info->ptr) != delim)) {
 		info->ptr++;
-		len ++;
-        }
+		len++;
+	}
 
 	if (len == 0) {
 		ERR(handle, "expected non-empty string, but did not "
-			"find one (%s: %u):\n%s", info->filename, info->lineno,
-			info->orig_line);
-			goto err;
+		    "find one (%s: %u):\n%s", info->filename, info->lineno,
+		    info->orig_line);
+		goto err;
 	}
 
-	tmp_str = (char*) malloc(len + 1);
+	tmp_str = (char *)malloc(len + 1);
 	if (!tmp_str) {
 		ERR(handle, "out of memory");
 		goto err;
 	}
 
 	strncpy(tmp_str, start, len);
-	*(tmp_str + len)= '\0';
+	*(tmp_str + len) = '\0';
 	*str = tmp_str;
 	return STATUS_SUCCESS;
 
-	err:
+      err:
 	ERR(handle, "could not fetch string value");
 	return STATUS_ERR;
-} 
+}
