@@ -34,15 +34,18 @@
 #include <string.h>
 #include <unistd.h>
 
-void test_semanage_is_prefix(void);
-void test_semanage_split_on_space(void);
-void test_semanage_split(void);
-void test_semanage_list(void);
-void test_semanage_str_count(void);
-void test_semanage_rtrim(void);
-void test_semanage_str_replace(void);
-void test_semanage_findval(void);
-void test_slurp_file_filter(void);
+#include "utilities.h"
+#include "test_utilities.h"
+
+static void test_semanage_is_prefix(void);
+static void test_semanage_split_on_space(void);
+static void test_semanage_split(void);
+static void test_semanage_list(void);
+static void test_semanage_str_count(void);
+static void test_semanage_rtrim(void);
+static void test_semanage_str_replace(void);
+static void test_semanage_findval(void);
+static void test_slurp_file_filter(void);
 
 char fname[] = {
 	'T', 'E', 'S', 'T', '_', 'T', 'E', 'M', 'P', '_', 'X', 'X', 'X', 'X',
@@ -120,7 +123,7 @@ int semanage_utilities_add_tests(CU_pSuite suite)
 	return CU_get_error();
 }
 
-void test_semanage_is_prefix(void)
+static void test_semanage_is_prefix(void)
 {
 	const char *str = "some string";
 	const char *pre = "some";
@@ -132,7 +135,7 @@ void test_semanage_is_prefix(void)
 	CU_ASSERT_FALSE(semanage_is_prefix(str, not_pre));
 }
 
-void test_semanage_split_on_space(void)
+static void test_semanage_split_on_space(void)
 {
 	char *str = strdup("   foo   bar    baz");
 	char *temp;
@@ -140,24 +143,28 @@ void test_semanage_split_on_space(void)
 	if (!str) {
 		CU_FAIL
 		    ("semanage_split_on_space: unable to perform test, no memory");
+		return;
 	}
 	temp = semanage_split_on_space(str);
+	CU_ASSERT_PTR_NOT_NULL_FATAL(temp);
 	CU_ASSERT_STRING_EQUAL(temp, "bar    baz");
 	free(str);
 	str = temp;
 
 	temp = semanage_split_on_space(str);
+	CU_ASSERT_PTR_NOT_NULL_FATAL(temp);
 	CU_ASSERT_STRING_EQUAL(temp, "baz");
 	free(str);
 	str = temp;
 
 	temp = semanage_split_on_space(str);
+	CU_ASSERT_PTR_NOT_NULL_FATAL(temp);
 	CU_ASSERT_STRING_EQUAL(temp, "");
 	free(str);
 	free(temp);
 }
 
-void test_semanage_split(void)
+static void test_semanage_split(void)
 {
 	char *str = strdup("foo1 foo2   foo:bar:");
 	char *temp;
@@ -168,27 +175,31 @@ void test_semanage_split(void)
 		return;
 	}
 	temp = semanage_split(str, NULL);
+	CU_ASSERT_PTR_NOT_NULL_FATAL(temp);
 	CU_ASSERT_STRING_EQUAL(temp, "foo2   foo:bar:");
 	free(str);
 	str = temp;
 
 	temp = semanage_split(str, "");
+	CU_ASSERT_PTR_NOT_NULL_FATAL(temp);
 	CU_ASSERT_STRING_EQUAL(temp, "foo:bar:");
 	free(str);
 	str = temp;
 
 	temp = semanage_split(str, ":");
+	CU_ASSERT_PTR_NOT_NULL_FATAL(temp);
 	CU_ASSERT_STRING_EQUAL(temp, "bar:");
 	free(str);
 	str = temp;
 
 	temp = semanage_split(str, ":");
+	CU_ASSERT_PTR_NOT_NULL_FATAL(temp);
 	CU_ASSERT_STRING_EQUAL(temp, "");
 	free(str);
 	free(temp);
 }
 
-void test_semanage_list(void)
+static void test_semanage_list(void)
 {
 	semanage_list_t *list = NULL;
 	semanage_list_t *ptr = NULL;
@@ -237,7 +248,7 @@ void test_semanage_list(void)
 	CU_ASSERT_PTR_NULL(list);
 }
 
-void test_semanage_str_count(void)
+static void test_semanage_str_count(void)
 {
 	const char *test_string = "abaababbaaaba";
 
@@ -246,7 +257,7 @@ void test_semanage_str_count(void)
 	CU_ASSERT_EQUAL(semanage_str_count(test_string, 'b'), 5);
 }
 
-void test_semanage_rtrim(void)
+static void test_semanage_rtrim(void)
 {
 	char *str = strdup("/blah/foo/bar/baz/");
 
@@ -262,7 +273,7 @@ void test_semanage_rtrim(void)
 	free(str);
 }
 
-void test_semanage_str_replace(void)
+static void test_semanage_str_replace(void)
 {
 	const char *test_str = "Hello, I am %{USERNAME} and my id is %{USERID}";
 	char *str1, *str2;
@@ -291,31 +302,34 @@ void test_semanage_str_replace(void)
 	free(str1);
 }
 
-void test_semanage_findval(void)
+static void test_semanage_findval(void)
 {
 	char *tok;
 	if (!fptr) {
 		CU_FAIL_FATAL("Temporary file was not created, aborting test.");
 	}
 	tok = semanage_findval(fname, "one", NULL);
+	CU_ASSERT_PTR_NOT_NULL_FATAL(tok);
 	CU_ASSERT_STRING_EQUAL(tok, "");
 	free(tok);
 	rewind(fptr);
 	tok = semanage_findval(fname, "one", "");
+	CU_ASSERT_PTR_NOT_NULL_FATAL(tok);
 	CU_ASSERT_STRING_EQUAL(tok, "");
 	free(tok);
 	rewind(fptr);
 	tok = semanage_findval(fname, "sigma", "=");
+	CU_ASSERT_PTR_NOT_NULL_FATAL(tok);
 	CU_ASSERT_STRING_EQUAL(tok, "foo");
 	free(tok);
 }
 
-int PREDICATE(const char *str)
+static int PREDICATE(const char *str)
 {
 	return semanage_is_prefix(str, "#");
 }
 
-void test_slurp_file_filter(void)
+static void test_slurp_file_filter(void)
 {
 	semanage_list_t *data, *tmp;
 	int cnt = 0;
